@@ -1,7 +1,7 @@
 package App::pod2wp;
 
-our $DATE = '2017-07-03'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2021-05-25'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -398,7 +398,7 @@ App::pod2wp - Publish POD document to WordPress as blog post
 
 =head1 VERSION
 
-This document describes version 0.004 of App::pod2wp (from Perl distribution App-pod2wp), released on 2017-07-03.
+This document describes version 0.005 of App::pod2wp (from Perl distribution App-pod2wp), released on 2021-05-25.
 
 =head1 FUNCTIONS
 
@@ -407,7 +407,7 @@ This document describes version 0.004 of App::pod2wp (from Perl distribution App
 
 Usage:
 
- pod2wp(%args) -> [status, msg, result, meta]
+ pod2wp(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Publish POD document to WordPress as blog post.
 
@@ -527,6 +527,7 @@ setting.
 
 =item * B<username>* => I<str>
 
+
 =back
 
 Special arguments:
@@ -535,17 +536,17 @@ Special arguments:
 
 =item * B<-dry_run> => I<bool>
 
-Pass -dry_run=>1 to enable simulation mode.
+Pass -dry_run=E<gt>1 to enable simulation mode.
 
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
+($reason) is a string containing error message, or "OK" if status is
+200. Third element ($payload) is optional, the actual result. Fourth
+element (%result_meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
@@ -566,22 +567,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-
-L<org2wp>.
-
-L<html2wp>.
-
-L<wp-xmlrpc>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
